aboutsummaryrefslogtreecommitdiffstats
path: root/summary.h
diff options
context:
space:
mode:
Diffstat (limited to 'summary.h')
-rw-r--r--summary.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/summary.h b/summary.h
index ed64ae669a..c12d27c9d2 100644
--- a/summary.h
+++ b/summary.h
@@ -1,7 +1,7 @@
/* summary.h
* Definitions for capture file summary data
*
- * $Id: summary.h,v 1.5 2000/08/21 18:20:12 deniel Exp $
+ * $Id: summary.h,v 1.6 2001/02/11 09:28:15 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@zing.org>
@@ -40,7 +40,8 @@ typedef struct _summary_tally {
long file_length; /* file length in bytes */
int encap_type; /* wiretap encapsulation type */
int snap; /* snapshot length */
- int drops; /* number of packet drops */
+ gboolean drops_known; /* TRUE if number of packet drops is known */
+ guint32 drops; /* number of packet drops */
const char *iface; /* interface name */
const char *dfilter; /* display filter */
const char *cfilter; /* capture filter */